from django.contrib import admin
from django.http.response import HttpResponseRedirect
from django.urls import path
from django.db.models import CASCADE, AutoField, OneToOneField
from django.views.generic import View
from django.utils.translation import gettext as _
from .models import *


@admin.action(description=_("Regenerate traits"))
def regenerate(modeladmin, request, queryset):
    for obj in queryset:
        obj.regenerate()


@admin.register(Keyword)
class KeywordAdmin(admin.ModelAdmin):
    """
    Admin Interface for Keyword
    """
    list_display = ["text_en", "text_de"]


@admin.register(Link)
class LinkAdmin(admin.ModelAdmin):
    """
    Admin Interface for Links
    """
    list_display = ["title_en", "title_de", "url", "favicon", "personal"]
    ordering = ['title_de', 'title_en']
    actions = [regenerate]
    change_list_template = "admin/links.html"

    def get_urls(self):
        urls = super().get_urls()
        my_urls = [
            path('sync/', self.sync_with_fs),
        ]
        return my_urls + urls

    def sync_with_fs(self, request):
        Link.sync_with_fs()
        return HttpResponseRedirect("../")
